@@ -130,7 +130,7 @@ module SiSU_CGI_SQL
       <<-'WOK_SQL'
 #Common TOP
       @@offset=0
-      @base="#{@hosturl_db}/#{@stub_default}.cgi" #fix sqlite
+      @base="#{@hosturl_cgi}/#{@stub_default}.cgi" #fix sqlite
       @@canned_search_url=@base
       @color_heading='#DDFFAA'
       @color_match='#ffff48'
